@@ -288,7 +288,7 @@ class EloquaBulkClient(object):
                 '''custom_object_name is required'''
             )
 
-        url = "{base_url}/{entity}?q='name={parentName}'".format(
+        url = "{base_url}/{entity}?q=name='{parentName}'".format(
             base_url=self.bulk_url,
             entity='customObjects',
             parentName=custom_object_name)
